@@ -400,7 +400,19 @@ def command_scenario(args):
             help='center latitude of the scenario (default: %default)')
         parser.add_option(
             '--radius', dest='radius', type=float, default=100.,
-            help='radius of the the scenario in [km] (default: %default)')
+            help='radius of the scenario in [km] (default: %default)')
+        parser.add_option(
+            '--source-radius', dest='source_radius', type=float, default=10.,
+            help='radius of the source area in [km] (default: %default)')
+        parser.add_option(
+            '--stations-paths', dest='stations_paths', type=str, default=None,
+            help='paths to a Pyrocko station file, seperated by \',\''
+                 '(default: %default)')
+        parser.add_option(
+            '--stationxml-paths', dest='stationxml_paths', type=str,
+            default=None,
+            help='paths to StationXML files, seperated by \',\''
+                 '(default: %default)')
         parser.add_option(
             '--gf-waveforms', dest='store_waveforms', type=str,
             default=STORE_WAVEFORMS,
@@ -418,6 +430,16 @@ def command_scenario(args):
             '--gf-store-superdirs',
             dest='gf_store_superdirs',
             help='Comma-separated list of directories containing GF stores')
+        parser.add_option(
+            '--no-map',
+            dest='make_map',
+            default=True,
+            action='store_false',
+            help='suppress generation of map')
+        parser.add_option(
+            '--rebuild',
+            dest='rebuild', action='store_true', default=False,
+            help='Rebuild a manually configured grond scenario')
 
     parser, options, args = cl_parse('scenario', args, setup)
 
@@ -432,16 +454,33 @@ def command_scenario(args):
         sys.exit(1)
 
     from grond import scenario as grond_scenario
+
     try:
         scenario = grond_scenario.GrondScenario(
             project_dir,
             center_lat=options.lat, center_lon=options.lon,
             radius=options.radius*km)
 
+        scenario.rebuild = options.rebuild
+        if options.rebuild:
+            options.force = True
+
         if 'waveforms' in options.targets:
+            if options.stationxml_paths:
+                options.stationxml_paths = [
+                    op.abspath(path) for path in
+                    options.stationxml_paths.split(',')]
+
+            if options.stations_paths:
+                options.stations_paths = [
+                    op.abspath(path) for path in
+                    options.stations_paths.split(',')]
+
             obs = grond_scenario.WaveformObservation(
                 nstations=options.nstations,
-                store_id=options.store_waveforms)
+                store_id=options.store_waveforms,
+                stations_paths=options.stations_paths,
+                stationxml_paths=options.stationxml_paths)
             scenario.add_observation(obs)
 
         if 'insar' in options.targets:
@@ -458,6 +497,7 @@ def command_scenario(args):
         if options.problem == 'cmt':
             problem = grond_scenario.DCSourceProblem(
                 nevents=options.nevents,
+                radius=options.source_radius*km,
                 magnitude_min=options.magnitude_range[0],
                 magnitude_max=options.magnitude_range[1])
         elif options.problem == 'rectangular':
@@ -468,7 +508,8 @@ def command_scenario(args):
         scenario.build(
             force=options.force,
             interactive=True,
-            gf_store_superdirs=gf_store_superdirs)
+            gf_store_superdirs=gf_store_superdirs,
+            make_map=options.make_map)
 
         logger.info(CLIHints('scenario',
                              config=scenario.get_grond_config_path(),
@@ -1016,6 +1057,12 @@ def command_export(args):
             '--output', dest='filename', metavar='FILE',
             help='write output to FILE')
 
+        parser.add_option(
+            '--effective-lat-lon', dest='effective_lat_lon',
+            action='store_true',
+            help='convert north_shift/east_shift offsets to true lat/lon '
+                 'coordinates (when outputting event objects).')
+
     parser, options, args = cl_parse('export', args, setup)
     if len(args) < 2:
         help_and_die(parser, 'arguments required')
@@ -1044,7 +1091,8 @@ def command_export(args):
             filename=options.filename,
             type=options.type,
             pnames=pnames,
-            selection=options.selection)
+            selection=options.selection,
+            effective_lat_lon=options.effective_lat_lon)
 
     except grond.GrondError as e:
         die(str(e))
