@@ -356,7 +356,7 @@ def check(
 
                         tobs_shift_group.append(tobs_shift)
 
-                    tcuts = num.array(tcuts, dtype=num.float)
+                    tcuts = num.array(tcuts, dtype=float)
 
                     tdata.append((
                         tfade,
@@ -394,7 +394,7 @@ def check(
                                 debug=True)
 
                     except NotFound as e:
-                        logger.warn(str(e))
+                        logger.warning(str(e))
                         continue
 
                     trs_projected = copy.deepcopy(trs_projected)
@@ -509,66 +509,68 @@ def process_event(ievent, g_data_id):
     config = environment.get_config()
     event_name = environment.get_selected_event_names()[ievent]
     nevents = environment.nevents_selected
-    tstart = time.time()
 
     ds = config.get_dataset(event_name)
     event = ds.get_event()
     problem = config.get_problem(event)
 
-    synt = ds.synthetic_test
-    if synt:
-        problem.base_source = problem.get_source(synt.get_x())
-
-    check_problem(problem)
-
-    rundir = expand_template(
-        config.rundir_template,
-        dict(problem_name=problem.name))
-    environment.set_rundir_path(rundir)
-
-    if op.exists(rundir):
-        if preserve:
-            nold_rundirs = len(glob.glob(rundir + '*'))
-            shutil.move(rundir, rundir+'-old-%d' % (nold_rundirs))
-        elif force:
-            shutil.rmtree(rundir)
-        else:
-            logger.warn('Skipping problem "%s": rundir already exists: %s' %
-                        (problem.name, rundir))
-            return
-
-    util.ensuredir(rundir)
-
-    logger.info(
-        'Starting event %i / %i' % (ievent+1, nevents))
-
-    logger.info('Rundir: %s' % rundir)
-
-    logger.info('Analysing problem "%s".' % problem.name)
-
-    for analyser_conf in config.analyser_configs:
-        analyser = analyser_conf.get_analyser()
-        analyser.analyse(problem, ds)
-
-    basepath = config.get_basepath()
-    config.change_basepath(rundir)
-    guts.dump(config, filename=op.join(rundir, 'config.yaml'))
-    config.change_basepath(basepath)
-
-    optimiser = config.optimiser_config.get_optimiser()
-    optimiser.set_nthreads(nthreads)
-
-    optimiser.init_bootstraps(problem)
-    problem.dump_problem_info(rundir)
-
+    tstart = time.time()
     monitor = None
-
-    xs_inject = None
-    synt = ds.synthetic_test
-    if synt and synt.inject_solution:
-        xs_inject = synt.get_x()[num.newaxis, :]
-
+    rundir = None
     try:
+
+        synt = ds.synthetic_test
+        if synt:
+            problem.base_source = problem.get_source(synt.get_x())
+
+        check_problem(problem)
+
+        rundir = expand_template(
+            config.rundir_template,
+            dict(problem_name=problem.name))
+        environment.set_rundir_path(rundir)
+
+        if op.exists(rundir):
+            if preserve:
+                nold_rundirs = len(glob.glob(rundir + '*'))
+                shutil.move(rundir, rundir+'-old-%d' % (nold_rundirs))
+            elif force:
+                shutil.rmtree(rundir)
+            else:
+                logger.warning(
+                    'Skipping problem "%s": rundir already exists: %s' % (
+                        problem.name, rundir))
+                return
+
+        util.ensuredir(rundir)
+
+        logger.info(
+            'Starting event %i / %i' % (ievent+1, nevents))
+
+        logger.info('Rundir: %s' % rundir)
+
+        logger.info('Analysing problem "%s".' % problem.name)
+
+        for analyser_conf in config.analyser_configs:
+            analyser = analyser_conf.get_analyser()
+            analyser.analyse(problem, ds)
+
+        basepath = config.get_basepath()
+        config.change_basepath(rundir)
+        guts.dump(config, filename=op.join(rundir, 'config.yaml'))
+        config.change_basepath(basepath)
+
+        optimiser = config.optimiser_config.get_optimiser()
+        optimiser.set_nthreads(nthreads)
+
+        optimiser.init_bootstraps(problem)
+        problem.dump_problem_info(rundir)
+
+        xs_inject = None
+        synt = ds.synthetic_test
+        if synt and synt.inject_solution:
+            xs_inject = synt.get_x()[num.newaxis, :]
+
         if xs_inject is not None:
             from .optimisers import highscore
             if not isinstance(optimiser, highscore.HighScoreOptimiser):
@@ -601,8 +603,9 @@ def process_event(ievent, g_data_id):
     logger.info(
         'Stop %i / %i (%g min)' % (ievent+1, nevents, (tstop - tstart)/60.))
 
-    logger.info(
-        'Done with problem "%s", rundir is "%s".' % (problem.name, rundir))
+    if rundir:
+        logger.info(
+            'Done with problem "%s", rundir is "%s".' % (problem.name, rundir))
 
 
 class ParameterStats(Object):
@@ -679,19 +682,27 @@ def format_stats(rs, fmt):
     values = []
     headers = []
     for x in fmt:
-        pname, qname = x.split('.')
-        pindex = pname_to_pindex[pname]
-        values.append(getattr(rs.parameter_stats_list[pindex], qname))
-        headers.append(x)
+        if x == 'problem.name':
+            headers.append(x)
+            values.append('%-16s' % rs.problem.name)
+        else:
+            pname, qname = x.split('.')
+            pindex = pname_to_pindex[pname]
+            values.append(
+                '%16.7g' % getattr(rs.parameter_stats_list[pindex], qname))
+            headers.append(x)
 
-    return ' '.join('%16.7g' % v for v in values)
+    return ' '.join(values)
 
 
 def export(
-        what, rundirs, type=None, pnames=None, filename=None, selection=None):
+        what, rundirs, type=None, pnames=None, filename=None, selection=None,
+        effective_lat_lon=False):
 
     if pnames is not None:
-        pnames_clean = [pname.split('.')[0] for pname in pnames]
+        pnames_clean = [
+            pname.split('.')[0] for pname in pnames
+            if not pname.startswith('problem.')]
         shortform = all(len(pname.split('.')) == 2 for pname in pnames)
     else:
         pnames_clean = None
@@ -729,14 +740,21 @@ def export(
 
         elif type == 'source':
             source = problem.get_source(x)
+            if effective_lat_lon:
+                source.set_origin(*source.effective_latlon)
             guts.dump(source, stream=out)
 
         elif type == 'event':
             ev = problem.get_source(x).pyrocko_event()
+            if effective_lat_lon:
+                ev.set_origin(*ev.effective_latlon)
+
             model.dump_events([ev], stream=out)
 
         elif type == 'event-yaml':
             ev = problem.get_source(x).pyrocko_event()
+            if effective_lat_lon:
+                ev.set_origin(*ev.effective_latlon)
             guts.dump_all([ev], stream=out)
 
         else:
