@@ -150,8 +150,10 @@ class Dataset(object):
                             'Station "%s" has vertical component'
                             ' information only, adding mocked channels.'
                             % station.nsl_string())
-                        station.add_channel(model.Channel('N'))
-                        station.add_channel(model.Channel('E'))
+                        station.add_channel(
+                            model.Channel(channels[0].name[:-1] + 'N'))
+                        station.add_channel(
+                            model.Channel(channels[0].name[:-1] + 'E'))
 
                     self.stations[station.nsl()] = station
 
@@ -176,7 +178,7 @@ class Dataset(object):
         cachedirname = config.config().cache_dir
 
         logger.debug('Selecting waveform files %s...' % quote_paths(paths))
-        fns = util.select_files(paths, regex=regex,
+        fns = util.select_files(paths, include=regex,
                                 show_progress=show_progress)
         cache = pile.get_cache(cachedirname)
         logger.debug('Scanning waveform files %s...' % quote_paths(paths))
@@ -219,7 +221,7 @@ class Dataset(object):
             clippings[nslc].append(marker.tmin)
 
         for k, times in clippings.items():
-            atimes = num.array(times, dtype=num.float)
+            atimes = num.array(times, dtype=float)
             if k not in self.clippings:
                 self.clippings[k] = atimes
             else:
@@ -277,7 +279,7 @@ class Dataset(object):
     def add_gnss_campaigns(self, paths):
         paths = util.select_files(
             paths,
-            regex=r'\.yml|\.yaml',
+            include=r'\.yml|\.yaml',
             show_progress=False)
 
         for path in paths:
@@ -298,7 +300,7 @@ class Dataset(object):
         logger.info('Loading kite InSAR scenes...')
         paths = util.select_files(
             paths,
-            regex=r'\.npz',
+            include=r'\.npz',
             show_progress=False)
 
         for path in paths:
@@ -609,7 +611,7 @@ class Dataset(object):
                 trs_restituted.append(
                     tr.transfer(
                         tfade=tfade, freqlimits=freqlimits,
-                        transfer_function=resp, invert=True))
+                        transfer_function=resp, invert=True, demean=True))
 
             except trace.InfiniteResponse:
                 raise NotFound(
@@ -1085,10 +1087,10 @@ class DatasetConfig(HasPaths):
                 if isinstance(p, list):
                     for path in p:
                         if not op.exists(path):
-                            logger.warn('Path %s does not exist.' % path)
+                            logger.warning('Path %s does not exist.' % path)
                 else:
                     if not op.exists(p):
-                        logger.warn('Path %s does not exist.' % p)
+                        logger.warning('Path %s does not exist.' % p)
 
                 return p
 
