@@ -80,7 +80,7 @@ class Sample(Object):
 
     '''Sample model with context about how it was generated.'''
 
-    model = Array.T(shape=(None,), dtype=num.float, serialize_as='list')
+    model = Array.T(shape=(None,), dtype=num.float64, serialize_as='list')
     iphase = Int.T(optional=True)
     ichain_base = Int.T(optional=True)
     ilink_base = Int.T(optional=True)
@@ -90,7 +90,7 @@ class Sample(Object):
         self.model = problem.preconstrain(self.model)
 
     def pack_context(self):
-        i = num.zeros(4, dtype=num.int)
+        i = num.zeros(4, dtype=int)
         i[:] = (
             fnone(self.iphase),
             fnone(self.ichain_base),
@@ -143,7 +143,7 @@ class SamplerPhase(Object):
 
 class InjectionSamplerPhase(SamplerPhase):
     xs_inject = Array.T(
-        dtype=num.float, shape=(None, None),
+        dtype=num.float64, shape=(None, None),
         help='Array with the reference model.')
 
     def get_raw_sample(self, problem, iiter, chains):
@@ -232,7 +232,7 @@ class DirectedSamplerPhase(SamplerPhase):
 
         ntries_sample = 0
         if self.sampler_distribution == 'normal':
-            x = num.zeros(npar, dtype=num.float)
+            x = num.zeros(npar, dtype=float)
             sx = chains.standard_deviation_models(
                 ichain_choice, self.standard_deviation_estimator)
 
@@ -267,7 +267,7 @@ class DirectedSamplerPhase(SamplerPhase):
                 x[ipar] = v
 
         elif self.sampler_distribution == 'multivariate_normal':
-            ok_mask_sum = num.zeros(npar, dtype=num.int)
+            ok_mask_sum = num.zeros(npar, dtype=int)
             while True:
                 ntries_sample += 1
                 xcandi = rstate.multivariate_normal(
@@ -337,15 +337,15 @@ class Chains(object):
         self.nchains = nchains
         self.nlinks_cap = nlinks_cap
         self.chains_m = num.zeros(
-            (self.nchains, nlinks_cap), dtype=num.float)
+            (self.nchains, nlinks_cap), dtype=float)
         self.chains_i = num.zeros(
-            (self.nchains, nlinks_cap), dtype=num.int)
+            (self.nchains, nlinks_cap), dtype=int)
         self.nlinks = 0
         self.nread = 0
 
-        self.accept_sum = num.zeros(self.nchains, dtype=num.int)
+        self.accept_sum = num.zeros(self.nchains, dtype=int)
         self._acceptance_history = num.zeros(
-            (self.nchains, 1024), dtype=num.bool)
+            (self.nchains, 1024), dtype=bool)
 
         history.add_listener(self)
 
@@ -376,10 +376,10 @@ class Chains(object):
 
             if self.nlinks == self.nlinks_cap:
                 accept = (chains_i[:, self.nlinks_cap-1] != nread) \
-                    .astype(num.bool)
+                    .astype(bool)
                 self.nlinks -= 1
             else:
-                accept = num.ones(self.nchains, dtype=num.bool)
+                accept = num.ones(self.nchains, dtype=bool)
 
             self._append_acceptance(accept)
             self.accept_sum += accept
@@ -448,7 +448,7 @@ class Chains(object):
     def _append_acceptance(self, acceptance):
         if self.nread >= self._acceptance_history.shape[1]:
             new_buf = num.zeros(
-                (self.nchains, nextpow2(self.nread+1)), dtype=num.bool)
+                (self.nchains, nextpow2(self.nread+1)), dtype=bool)
             new_buf[:, :self._acceptance_history.shape[1]] = \
                 self._acceptance_history
             self._acceptance_history = new_buf
@@ -557,7 +557,7 @@ class HighScoreOptimiser(Optimiser):
         if self._correlated_weights is None:
             corr = dict()
             misfit_idx = num.cumsum(
-                [0.] + [t.nmisfits for t in problem.targets], dtype=num.int)
+                [0.] + [t.nmisfits for t in problem.targets], dtype=int)
 
             for it, target in enumerate(problem.targets):
                 weights = target.get_correlated_weights(
@@ -788,7 +788,7 @@ def load_optimiser_history(dirname, problem):
         data1 = num.fromfile(
             f,
             dtype='<i1',
-            count=nmodels*(problem.nbootstrap+1)).astype(num.bool)
+            count=nmodels*(problem.nbootstrap+1)).astype(bool)
 
     accepted = data1.reshape((nmodels, problem.nbootstrap+1))
 
