@@ -107,7 +107,7 @@ corresponding misfit values.
         iorder = num.arange(iorder.size)
 
         if misfit_cutoff is None:
-            ibest = num.ones(gms.size, dtype=num.bool)
+            ibest = num.ones(gms.size, dtype=bool)
         else:
             ibest = gms < misfit_cutoff
 
@@ -317,13 +317,13 @@ modified.
 
         problem = history.problem
         if not problem:
-            logger.warn('Problem not set.')
+            logger.warning('Problem not set.')
             return []
 
         models = history.models
 
         if models.size == 0:
-            logger.warn('Empty models vector.')
+            logger.warning('Empty models vector.')
             return []
 
         for target in problem.targets:
