@@ -147,7 +147,7 @@ class Problem(Object):
         return ADict(params)
 
     def get_parameter_array(self, d):
-        arr = num.zeros(self.nparameters, dtype=num.float)
+        arr = num.zeros(self.nparameters, dtype=float)
         for ip, p in enumerate(self.parameters):
             if p.name in d.keys():
                 arr[ip] = d[p.name]
@@ -358,7 +358,7 @@ class Problem(Object):
                 r = target.target_ranges[p.name_nogroups]
                 out.append((r.start, r.stop))
 
-        return num.array(out, dtype=num.float)
+        return num.array(out, dtype=float)
 
     def get_dependant_bounds(self):
         return num.zeros((0, 2))
@@ -508,7 +508,7 @@ class Problem(Object):
 
     def make_family_mask(self):
         family_names = set()
-        families = num.zeros(self.nmisfits, dtype=num.int)
+        families = num.zeros(self.nmisfits, dtype=int)
 
         idx = 0
         for itarget, target in enumerate(self.targets):
@@ -753,19 +753,19 @@ class ModelHistory(object):
 
             models_buffer = num.zeros(
                 (nmodels_capacity_new, self.problem.nparameters),
-                dtype=num.float)
+                dtype=float)
             misfits_buffer = num.zeros(
                 (nmodels_capacity_new, self.problem.nmisfits, 2),
-                dtype=num.float)
+                dtype=float)
             sample_contexts_buffer = num.zeros(
                 (nmodels_capacity_new, 4),
-                dtype=num.int)
+                dtype=int)
             sample_contexts_buffer.fill(-1)
 
             if self.nchains is not None:
                 bootstraps_buffer = num.zeros(
                     (nmodels_capacity_new, self.nchains),
-                    dtype=num.float)
+                    dtype=float)
 
             ncopy = min(self.nmodels, nmodels_capacity_new)
 
@@ -912,7 +912,7 @@ class ModelHistory(object):
             with open(path, 'rb') as f:
                 self._attributes[name] = num.fromfile(
                     f, dtype='<i4',
-                    count=self.nmodels).astype(num.int)
+                    count=self.nmodels).astype(int)
 
             assert self._attributes[name].shape == (self.nmodels,)
 
@@ -922,7 +922,7 @@ class ModelHistory(object):
         if not StringID.regex.match(name):
             raise InvalidAttributeName(name)
 
-        attribute = attribute.astype(num.int)
+        attribute = attribute.astype(int)
         assert attribute.shape == (self.nmodels,)
 
         apath = op.join(self.path, 'attributes')
@@ -965,7 +965,7 @@ class ModelHistory(object):
                 by_cluster.append(by_cluster.pop(0))
 
         except NoSuchAttribute:
-            logger.warn(
+            logger.warning(
                 'Attribute %s not set in run %s.\n'
                 '  Skipping model retrieval by clusters.' % (
                     cluster_attribute, self.problem.name))
@@ -1085,7 +1085,7 @@ def load_problem_data(dirname, problem, nmodels_skip=0, nchains=None):
             models = num.fromfile(
                     f, dtype='<f8',
                     count=nmodels * problem.nparameters)\
-                .astype(num.float)
+                .astype(float)
 
         models = models.reshape((nmodels, problem.nparameters))
 
@@ -1095,7 +1095,7 @@ def load_problem_data(dirname, problem, nmodels_skip=0, nchains=None):
             misfits = num.fromfile(
                     f, dtype='<f8',
                     count=nmodels*problem.nmisfits*2)\
-                .astype(num.float)
+                .astype(float)
         misfits = misfits.reshape((nmodels, problem.nmisfits, 2))
 
         chains = None
@@ -1106,7 +1106,7 @@ def load_problem_data(dirname, problem, nmodels_skip=0, nchains=None):
                 chains = num.fromfile(
                         f, dtype='<f8',
                         count=nmodels*nchains)\
-                    .astype(num.float)
+                    .astype(float)
 
             chains = chains.reshape((nmodels, nchains))
 
@@ -1117,7 +1117,7 @@ def load_problem_data(dirname, problem, nmodels_skip=0, nchains=None):
                 f.seek(nmodels_skip * 4 * 8)
                 sampler_contexts = num.fromfile(
                         f, dtype='<i8',
-                        count=nmodels*4).astype(num.int)
+                        count=nmodels*4).astype(int)
 
             sampler_contexts = sampler_contexts.reshape((nmodels, 4))
 
