@@ -173,8 +173,9 @@ parameter bounds and shows the model space of the optimsation. %s''' % sref)
         nselected = iselected
 
         if nselected < 2:
-            logger.warn('Cannot draw joinpar figures with less than two '
-                        'parameters selected.')
+            logger.warning(
+                'Cannot draw joinpar figures with less than two parameters '
+                'selected.')
             return []
 
         nfig = (nselected - 2) // nsubplots + 1
@@ -455,7 +456,7 @@ space.
                 try:
                     kde = scipy.stats.gaussian_kde(vs)
                 except Exception:
-                    logger.warn(
+                    logger.warning(
                         'Cannot create plot histogram with gaussian_kde: '
                         'possibly all samples have the same value.')
                     continue
@@ -553,7 +554,7 @@ best have similar symbol size and patterns.
         models = history.models
 
         if models.size == 0:
-            logger.warn('Empty models vector.')
+            logger.warning('Empty models vector.')
             return []
 
         # gms = problem.combine_misfits(history.misfits)
@@ -594,7 +595,7 @@ best have similar symbol size and patterns.
                      get_deco(source),
                      cluster_color(icluster)))
             else:
-                logger.warn(
+                logger.warning(
                     'Skipping display of cluster %i because figure height is '
                     'too small. Figure height should be at least %g cm.' % (
                         icluster, (3 + len(cluster_sources)
@@ -665,7 +666,7 @@ best have similar symbol size and patterns.
                             linewidth=1.0)
 
                     except beachball.BeachballError as e:
-                        logger.warn(str(e))
+                        logger.warning(str(e))
 
                         axes.annotate(
                             'ERROR',
@@ -852,7 +853,7 @@ high (blue) misfit.
                         linewidth=0.25)
 
                 except beachball.BeachballError as e:
-                    logger.warn(str(e))
+                    logger.warning(str(e))
 
         item = PlotItem(name='main')
         return [[item, fig]]
@@ -1014,7 +1015,7 @@ fitting solution.
                         zorder=1,
                         linewidth=0.25)
                 except beachball.BeachballError as e:
-                    logger.warn(str(e))
+                    logger.warning(str(e))
 
             else:
                 data.append((u, v))
@@ -1045,7 +1046,7 @@ fitting solution.
                 zorder=2,
                 linewidth=0.5)
         except beachball.BeachballError as e:
-            logger.warn(str(e))
+            logger.warning(str(e))
 
         mt = best_source.pyrocko_moment_tensor()
         u, v = hudson.project(mt)
@@ -1072,7 +1073,7 @@ fitting solution.
                     zorder=2,
                     linewidth=0.5)
             except beachball.BeachballError as e:
-                logger.warn(str(e))
+                logger.warning(str(e))
 
         item = PlotItem(
             name='main')
