@@ -92,47 +92,24 @@ function ReportIndexEntry(obj) {
 }
 
 var yaml_type_map = [
-    ['!grond.ReportInfo', Dummy],
     ['!grond.ReportIndexEntry', ReportIndexEntry],
-    ['!pf.Event', Dummy],
-    ['!pf.MomentTensor', Dummy],
-    ['!grond.ParameterStats', Dummy],
-    ['!grond.TargetBalancingAnalyserResult', Dummy],
-    ['!grond.NoiseAnalyserResult', Dummy],
-    ['!grond.ResultStats', Dummy],
-    ['!grond.MisfitConfig', Dummy],
-    ['!grond.WaveformMisfitTarget', Dummy],
-    ['!grond.WaveformMisfitConfig', Dummy],
-    ['!grond.WaveformTargetGroup', Dummy],
-    ['!grond.GNSSCampaignMisfitTarget', Dummy],
-    ['!grond.GNSSCampaignMisfitConfig', Dummy],
-    ['!grond.GNSSCampaignTargetGroup', Dummy],
-    ['!grond.SatelliteMisfitTarget', Dummy],
-    ['!grond.SatelliteMisfitConfig', Dummy],
-    ['!grond.SatelliteTargetGroup', Dummy],
-    ['!grond.PhaseRatioTarget', Dummy],
-    ['!grond.PhaseRatioTargetGroup', Dummy],
-    ['!grond.FeatureMeasure', Dummy],
-    ['!grond.CMTProblem', Dummy],
-    ['!grond.DoubleDCProblem', Dummy],
-    ['!grond.RectangularProblem', Dummy],
-    ['!grond.VolumePointProblem', Dummy],
-    ['!grond.VLVDProblem', Dummy],
-    ['!pf.MTSource', Dummy],
-    ['!pf.RectangularSource', Dummy],
-    ['!pf.DoubleDCSource', Dummy],
-    ['!pf.ExplosionSource', Dummy],
-    ['!pf.VLVDSource', Dummy],
-    ['!pf.HalfSinusoidSTF', Dummy],
-    ['!grond.PlotCollection', Dummy],
-    ['!grond.PlotGroup', Dummy],
-    ['!grond.PlotItem', Dummy],
-    ['!grond.PNG', Dummy],
-    ['!grond.PDF', Dummy],
-    ['!grond.VersionInfo', Dummy],
-    ['!grond.RunInfo', Dummy],
 ];
 
+function have_type(type_map, name) {
+    for (var i=0; i<type_map.length; i++) {
+        if (type_map[i][0] == name) {
+            return true;
+        }
+    }
+    return false;
+}
+
+for (var i=0; i<GUTS_TYPES.length; i++) {
+    if (!have_type(yaml_type_map, GUTS_TYPES[i])) {
+        yaml_type_map.push([GUTS_TYPES[i], Dummy]);
+    }
+}
+
 function make_constructor(type) {
     var type = type;
     var construct = function(data) {
@@ -291,6 +268,15 @@ angular.module('reportApp', ['ngRoute', 'ngSanitize'])
             return selected_problem_names;
         };
 
+        funcs.set_selected = function(problem_names) {
+            selected_problem_names.length = 0;
+            for (var i=0; i<problem_names.length; i++) {
+                selected_problem_names.push(problem_names[i]);
+            }
+            selected_problem_names.sort()
+        };
+
+
         funcs.is_selected = function(problem_name) {
             return includes(selected_problem_names, problem_name);
         };
@@ -420,6 +406,15 @@ angular.module('reportApp', ['ngRoute', 'ngSanitize'])
             return $filter('filter')(ordered_lines[order_skey], $scope.list_search_keyword);
         };
 
+        $scope.select_all_filtered = function() {
+            var lines = $scope.get_ordered_report_entries();
+            var problem_names = [];
+            for (var i=0; i<lines.length; i++) {
+                problem_names.push(
+                    lines[i].report_entry.problem_name);
+            }
+            rl.set_selected(problem_names);
+        };
     })
 
     .controller('ReportController', function(
@@ -564,15 +559,17 @@ angular.module('reportApp', ['ngRoute', 'ngSanitize'])
                 YamlDoc.query(
                     get_path(problem_name) + '/stats.yaml',
                     function(doc) {
-                        doc.title = 'Parameter Results';
-                        doc.name = 'parameter results';
-                        doc.variant = 'default';
-                        doc.section = 'run';
-                        doc.stats_path = get_path(problem_name) + '/stats.yaml';
-                        doc.feather_icon = 'book';
-                        doc.template = 'parameter-table';
+                        if (doc) {
+                            doc.title = 'Parameter Results';
+                            doc.name = 'parameter results';
+                            doc.variant = 'default';
+                            doc.section = 'run';
+                            doc.stats_path = get_path(problem_name) + '/stats.yaml';
+                            doc.feather_icon = 'book';
+                            doc.template = 'parameter-table';
 
-                        insert_group(problem_name, doc);
+                            insert_group(problem_name, doc);
+                        }
                     },
                     {schema: report_schema});
 
@@ -770,7 +767,11 @@ angular.module('reportApp', ['ngRoute', 'ngSanitize'])
         };
 
         $scope.doc_matches_keyword = function(doc) {
-            return ($filter('filter')(doc.items, $scope.keyword)).length > 0;
+            if (doc) {
+                return ($filter('filter')(doc.items, $scope.keyword)).length > 0;
+            } else {
+                return false;
+            }
         };
     })
 
