@@ -19,13 +19,13 @@ class RunInfo(Object):
             self.tags.append(tag)
             self.tags.sort()
         else:
-            logger.warn('While adding tag: tag already set: %s' % tag)
+            logger.warning('While adding tag: tag already set: %s' % tag)
 
     def remove_tag(self, tag):
         try:
             self.tags.remove(tag)
         except ValueError:
-            logger.warn('While removing tag: tag not set: %s' % tag)
+            logger.warning('While removing tag: tag not set: %s' % tag)
 
 
 def read_info(path):
