@@ -251,8 +251,11 @@ edge marking the upper fault edge. Complete data extent is shown.
                 except Exception as e:
                     logger.warning('could not plot hillshaded topo')
                     logger.exception(e)
+            rgb_arr = mappable.to_rgba(arr)
+            rgb_arr[num.isnan(arr)] = 1.
+            rgb_arr[scene.displacement_mask] = 1.
 
-            return mappable.to_rgba(arr)
+            return rgb_arr
 
         def draw_leaves(ax, scene, offset_e=0., offset_n=0.):
             rects = scene.quadtree.getMPLRectangles()
