@@ -165,7 +165,7 @@ def layout(source, targets, nxmax, nymax):
         y = dist * num.cos(num.deg2rad(azi))
         data.append((x, y, dist))
 
-    gxs, gys, dists = num.array(data, dtype=num.float).T
+    gxs, gys, dists = num.array(data, dtype=float).T
 
     iorder = num.argsort(dists)
 
@@ -189,7 +189,7 @@ def layout(source, targets, nxmax, nymax):
 
     distmax = num.max(dists)
 
-    availmask = num.ones(dists.shape[1], dtype=num.bool)
+    availmask = num.ones(dists.shape[1], dtype=bool)
     frame_to_target = {}
     for itarget, target in enumerate(targets_sorted):
         iframe = num.argmin(
@@ -555,7 +555,7 @@ traces.''')
                 all_syn_trs.append(result.processed_syn)
 
         if not all_syn_trs:
-            logger.warn('No traces to show!')
+            logger.warning('No traces to show!')
             return
 
         def skey(tr):
@@ -968,7 +968,7 @@ box, red).
                 all_syn_specs.append(result.spectrum_syn)
 
         if not all_syn_trs:
-            logger.warn('No traces to show!')
+            logger.warning('No traces to show!')
             return
 
         def skey(tr):
@@ -1319,10 +1319,8 @@ location of the source.
                             u'weighting factor of the corresponding target\'s '
                             u'contribution in the misfit function.')
             fig, ax, legend = self.plot_station_distribution(
-                azimuths, distances, ws[itargets], labels)
-            legend.set_title(
-                'Weight',
-                prop=dict(size=self.font_size))
+                azimuths, distances, ws[itargets], labels,
+                legend_title='Weight')
 
             yield (item, fig)
 
@@ -1334,10 +1332,8 @@ location of the source.
                                 u'misfit contribution for the globally best '
                                 u'source model.')
                 fig, ax, legend = self.plot_station_distribution(
-                    azimuths, distances, gcms[itargets], labels)
-                legend.set_title(
-                    'Contribution',
-                    prop=dict(size=self.font_size))
+                    azimuths, distances, gcms[itargets], labels,
+                    legend_title='Contribution')
 
                 yield (item, fig)
 
