@@ -10,7 +10,7 @@ from pyrocko.guts import (Object, String, Float, Bool, Int, StringChoice,
 from pyrocko.guts_array import Array
 
 from grond.dataset import NotFound
-from grond.meta import GrondError, nslcs_to_patterns
+from grond.meta import GrondError, store_t, nslcs_to_patterns
 
 from ..base import (MisfitConfig, MisfitTarget, MisfitResult, TargetGroup)
 from grond.meta import has_get_plot_classes
@@ -314,7 +314,7 @@ class TraceSpectrum(Object):
     channel = String.T()
     deltaf = Float.T(default=1.0)
     fmin = Float.T(default=0.0)
-    ydata = Array.T(shape=(None,), dtype=num.complex, serialize_as='list')
+    ydata = Array.T(shape=(None,), dtype=num.complex128, serialize_as='list')
 
     def get_ydata(self):
         return self.ydata
@@ -398,14 +398,14 @@ class WaveformMisfitTarget(gf.Target, MisfitTarget):
             w = self.manual_weight
             for analyser in self.analyser_results.values():
                 w *= analyser.weight
-            self._combined_weight = num.array([w], dtype=num.float)
+            self._combined_weight = num.array([w], dtype=float)
         return self._combined_weight
 
     def get_taper_params(self, engine, source):
         store = engine.get_store(self.store_id)
         config = self.misfit_config
-        tmin_fit = source.time + store.t(config.tmin, source, self)
-        tmax_fit = source.time + store.t(config.tmax, source, self)
+        tmin_fit = source.time + store_t(store, config.tmin, source, self)
+        tmax_fit = source.time + store_t(store, config.tmax, source, self)
         if config.fmin > 0.0:
             tfade = 1.0/config.fmin
         else:
@@ -678,7 +678,7 @@ tautoshift**2 / tautoshift_max**2``
 
     if result_mode == 'full':
         result = WaveformMisfitResult(
-            misfits=num.array([[m, n]], dtype=num.float),
+            misfits=num.array([[m, n]], dtype=float),
             processed_obs=tr_proc_obs,
             processed_syn=tr_proc_syn,
             filtered_obs=tr_obs.copy(),
@@ -691,7 +691,7 @@ tautoshift**2 / tautoshift_max**2``
 
     elif result_mode == 'sparse':
         result = WaveformMisfitResult(
-            misfits=num.array([[m, n]], dtype=num.float))
+            misfits=num.array([[m, n]], dtype=float))
     else:
         assert False
 
@@ -706,7 +706,7 @@ def _extend_extract(tr, tmin, tmax):
     itmax_frame = int(math.ceil(tmax/deltat))
     nframe = itmax_frame - itmin_frame + 1
     n = tr.data_len()
-    a = num.empty(nframe, dtype=num.float)
+    a = num.empty(nframe, dtype=float)
     itmin_tr = int(round(tr.tmin / deltat))
     itmax_tr = itmin_tr + n
     icut1 = min(max(0, itmin_tr - itmin_frame), nframe)
@@ -739,7 +739,7 @@ def _process(tr, tmin, tmax, taper, domain):
     elif domain in ('frequency_domain', 'log_frequency_domain'):
         ndata = tr_proc.ydata.size
         nfft = trace.nextpow2(ndata)
-        padded = num.zeros(nfft, dtype=num.float)
+        padded = num.zeros(nfft, dtype=float)
         padded[:ndata] = tr_proc.ydata
         spectrum = num.fft.rfft(padded)
         df = 1.0 / (tr_proc.deltat * nfft)
