@@ -6,7 +6,7 @@ def test_nanmedian():
 
     a = num.array([[1, 2, 3, 4, 5],
                    [1, None, 2, None, 3],
-                   [None, 1, 2, 3, None]], dtype=num.float)
+                   [None, 1, 2, 3, None]], dtype=float)
 
     res = meta.nanmedian(a, axis=0)
     for ix in range(a.shape[1]):
